arimaorder: Return the order of an ARIMA or ARFIMA model

View source: R/arima.R

arimaorderR Documentation

Return the order of an ARIMA or ARFIMA model

Description

Returns the order of a univariate ARIMA or ARFIMA model.

Usage

arimaorder(object)

Arguments

object

An object of class Arima, ar or fracdiff. Usually the result of a call to stats::arima(), Arima(), auto.arima(), stats::ar(), arfima() or fracdiff::fracdiff().

Value

A numerical vector giving the values p, d and q of the ARIMA or ARFIMA model. For a seasonal ARIMA model, the returned vector contains the values p, d, q, P, D, Q and m, where m is the period of seasonality.

Author(s)

Rob J Hyndman

See Also

stats::ar(), auto.arima, Arima(), stats::arima(), arfima().

Examples

WWWusage |> auto.arima() |> arimaorder()


forecast documentation built on March 18, 2026, 9:07 a.m.