| autoplot.decomposed.ts | R Documentation |
Produces a ggplot object of seasonally decomposed time series for objects of
class stl (created with stats::stl(), class seas (created with
seasonal::seas()), or class decomposed.ts (created with
stats::decompose()).
## S3 method for class 'decomposed.ts'
autoplot(object, labels = NULL, range.bars = NULL, ...)
## S3 method for class 'stl'
autoplot(object, labels = NULL, range.bars = TRUE, ...)
## S3 method for class 'StructTS'
autoplot(object, labels = NULL, range.bars = TRUE, ...)
## S3 method for class 'seas'
autoplot(object, labels = NULL, range.bars = NULL, ...)
## S3 method for class 'mstl'
autoplot(object, ...)
object |
Object of class |
labels |
Labels to replace "seasonal", "trend", and "remainder". |
range.bars |
Logical indicating if each plot should have a bar at its
right side representing relative size. If |
... |
Other plotting parameters to affect the plot. |
Returns an object of class ggplot.
Mitchell O'Hara-Wild
seasonal::seas(), stats::stl(), stats::decompose(),
stats::StructTS(), stats::plot.stl().
library(ggplot2)
co2 |>
decompose() |>
autoplot()
nottem |>
stl(s.window = "periodic") |>
autoplot()
## Not run:
library(seasonal)
seas(USAccDeaths) |> autoplot()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.