| dshw | R Documentation |
Returns forecasts using Taylor's (2003) Double-Seasonal Holt-Winters method.
dshw(
y,
period1 = NULL,
period2 = NULL,
h = 2 * max(period1, period2),
alpha = NULL,
beta = NULL,
gamma = NULL,
omega = NULL,
phi = NULL,
lambda = NULL,
biasadj = FALSE,
armethod = TRUE,
model = NULL
)
y |
Either an |
period1 |
Period of the shorter seasonal period. Only used if |
period2 |
Period of the longer seasonal period. Only used if |
h |
Number of periods for forecasting. |
alpha |
Smoothing parameter for the level. If |
beta |
Smoothing parameter for the slope. If |
gamma |
Smoothing parameter for the first seasonal period. If
|
omega |
Smoothing parameter for the second seasonal period. If
|
phi |
Autoregressive parameter. If |
lambda |
Box-Cox transformation parameter. If |
biasadj |
Use adjusted back-transformed mean for Box-Cox
transformations. If transformed data is used to produce forecasts and fitted
values, a regular back transformation will result in median forecasts. If
biasadj is |
armethod |
If |
model |
If it's specified, an existing model is applied to a new data set. |
Taylor's (2003) double-seasonal Holt-Winters method uses additive trend and
multiplicative seasonality, where there are two seasonal components which
are multiplied together. For example, with a series of half-hourly data, one
would set period1 = 48 for the daily period and period2 = 336 for
the weekly period. The smoothing parameter notation used here is different
from that in Taylor (2003); instead it matches that used in Hyndman et al
(2008) and that used for the ets() function.
An object of class forecast.
Rob J Hyndman
Taylor, J.W. (2003) Short-term electricity demand forecasting using double seasonal exponential smoothing. Journal of the Operational Research Society, 54, 799-805.
Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D. (2008) Forecasting with exponential smoothing: the state space approach, Springer-Verlag. https://robjhyndman.com/expsmooth/.
stats::HoltWinters(), ets().
## Not run:
fcast <- dshw(taylor)
plot(fcast)
t <- seq(0, 5, by = 1 / 20)
x <- exp(sin(2 * pi * t) + cos(2 * pi * t * 4) + rnorm(length(t), 0, 0.1))
fit <- dshw(x, 20, 5)
plot(fit)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.