| forecast.fracdiff | R Documentation |
Returns forecasts and other information for univariate ARIMA models.
## S3 method for class 'fracdiff'
forecast(
object,
h = 10,
level = c(80, 95),
fan = FALSE,
simulate = FALSE,
bootstrap = FALSE,
innov = NULL,
npaths = 5000,
lambda = object$lambda,
biasadj = attr(lambda, "biasadj"),
...
)
## S3 method for class 'Arima'
forecast(
object,
h = if (object$arma[5] > 1) 2 * object$arma[5] else 10,
level = c(80, 95),
fan = FALSE,
xreg = NULL,
simulate = FALSE,
bootstrap = FALSE,
innov = NULL,
npaths = 5000,
lambda = object$lambda,
biasadj = attr(lambda, "biasadj"),
...
)
## S3 method for class 'ar'
forecast(
object,
h = 10,
level = c(80, 95),
fan = FALSE,
simulate = FALSE,
bootstrap = FALSE,
innov = NULL,
npaths = 5000,
lambda = NULL,
biasadj = FALSE,
...
)
object |
An object of class |
h |
Number of periods for forecasting. If |
level |
Confidence levels for prediction intervals. |
fan |
If |
simulate |
If |
bootstrap |
If |
innov |
Optional matrix of future innovations to be used in
simulations. Ignored if |
npaths |
Number of sample paths used in computing simulated prediction intervals. |
lambda |
Box-Cox transformation parameter. If |
biasadj |
Use adjusted back-transformed mean for Box-Cox
transformations. If transformed data is used to produce forecasts and fitted
values, a regular back transformation will result in median forecasts. If
biasadj is |
... |
Other arguments are ignored. |
xreg |
Future values of any regression variables. A numerical vector or matrix of external regressors; it should not be a data frame. |
For Arima or ar objects, the function calls stats::predict.Arima() or
stats::predict.ar and constructs an object of class forecast from the
results. For fracdiff objects, the calculations are all done within
fracdiff::fracdiff() using the equations given by Peiris and Perera (1988).
An object of class forecast.
An object of class forecast is a list usually containing at least
the following elements:
A list containing information about the fitted model
The name of the forecasting method as a character string
Point forecasts as a time series
Lower limits for prediction intervals
Upper limits for prediction intervals
The confidence values associated with the prediction intervals
The original time series.
Residuals from the fitted model. For models with additive errors, the residuals will be x minus the fitted values.
Fitted values (one-step forecasts)
The function summary can be used to obtain and print a summary of the
results, while the functions plot and autoplot produce plots of the forecasts and
prediction intervals. The generic accessor functions fitted.values and residuals
extract various useful features from the underlying model.
Rob J Hyndman
Peiris, M. & Perera, B. (1988), On prediction with fractionally differenced ARIMA models, Journal of Time Series Analysis, 9(3), 215-220.
stats::predict.Arima(), stats::predict.ar(), auto.arima(),
Arima(), stats::arima(), stats::ar(), arfima().
fit <- Arima(WWWusage, c(3, 1, 0))
plot(forecast(fit))
library(fracdiff)
x <- fracdiff.sim(100, ma = -0.4, d = 0.3)$series
fit <- arfima(x)
plot(forecast(fit, h = 30))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.