| forecast.baggedModel | R Documentation |
Returns forecasts and other information for bagged models.
## S3 method for class 'baggedModel'
forecast(
object,
h = if (frequency(object$y) > 1) 2 * frequency(object$y) else 10,
...
)
object |
An object of class |
h |
Number of periods for forecasting. Default value is twice the largest seasonal period (for seasonal data) or ten (for non-seasonal data). |
... |
Other arguments, passed on to the |
Intervals are calculated as min and max values over the point forecasts from the models in the ensemble. I.e., the intervals are not prediction intervals, but give an indication of how different the forecasts within the ensemble are.
An object of class forecast.
An object of class forecast is a list usually containing at least
the following elements:
A list containing information about the fitted model
The name of the forecasting method as a character string
Point forecasts as a time series
Lower limits for prediction intervals
Upper limits for prediction intervals
The confidence values associated with the prediction intervals
The original time series.
Residuals from the fitted model. For models with additive errors, the residuals will be x minus the fitted values.
Fitted values (one-step forecasts)
The function summary can be used to obtain and print a summary of the
results, while the functions plot and autoplot produce plots of the forecasts and
prediction intervals. The generic accessor functions fitted.values and residuals
extract various useful features from the underlying model.
Christoph Bergmeir, Fotios Petropoulos
Bergmeir, C., R. J. Hyndman, and J. M. Benitez (2016). Bagging Exponential Smoothing Methods using STL Decomposition and Box-Cox Transformation. International Journal of Forecasting 32, 303-312.
baggedModel().
fit <- baggedModel(WWWusage)
fcast <- forecast(fit)
plot(fcast)
## Not run:
fit2 <- baggedModel(WWWusage, fn = "auto.arima")
fcast2 <- forecast(fit2)
plot(fcast2)
accuracy(fcast2)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.