| forecast.mean_model | R Documentation |
Returns forecasts and prediction intervals for a Gaussian iid model.
meanf() is a convenience function that combines mean_model() and forecast().
## S3 method for class 'mean_model'
forecast(
object,
h = 10,
level = c(80, 95),
fan = FALSE,
lambda = object$lambda,
biasadj = attr(object$lambda, "biasadj"),
bootstrap = FALSE,
npaths = 5000,
...
)
meanf(
y,
h = 10,
level = c(80, 95),
fan = FALSE,
lambda = NULL,
biasadj = FALSE,
bootstrap = FALSE,
npaths = 5000,
x = y
)
object |
An object of class |
h |
Number of periods for forecasting. Default value is twice the largest seasonal period (for seasonal data) or ten (for non-seasonal data). |
level |
Confidence levels for prediction intervals. |
fan |
If |
lambda |
Box-Cox transformation parameter. If |
biasadj |
Use adjusted back-transformed mean for Box-Cox
transformations. If transformed data is used to produce forecasts and fitted
values, a regular back transformation will result in median forecasts. If
biasadj is |
bootstrap |
If |
npaths |
Number of sample paths used in computing simulated prediction intervals. |
... |
Additional arguments not used. |
y |
a numeric vector or univariate time series of class |
x |
Deprecated. Included for backwards compatibility. |
The model assumes that the data are independent and identically distributed
Y_t \sim N(\mu,\sigma^2)
Forecasts are given by
Y_{n+h|n}=\mu
where \mu is estimated by the sample mean.
The function summary() is used to obtain and print a summary of the
results, while the function plot() produces a plot of the forecasts and
prediction intervals.
The generic accessor functions stats::fitted() and stats::residuals()
extract useful features of the object returned by mean_model().
An object of class forecast is a list usually containing at least
the following elements:
A list containing information about the fitted model
The name of the forecasting method as a character string
Point forecasts as a time series
Lower limits for prediction intervals
Upper limits for prediction intervals
The confidence values associated with the prediction intervals
The original time series.
Residuals from the fitted model. For models with additive errors, the residuals will be x minus the fitted values.
Fitted values (one-step forecasts)
The function summary can be used to obtain and print a summary of the
results, while the functions plot and autoplot produce plots of the forecasts and
prediction intervals. The generic accessor functions fitted.values and residuals
extract various useful features from the underlying model.
Rob J Hyndman
mean_model()
fit_nile <- mean_model(Nile)
fit_nile |> forecast(h = 10) |> autoplot()
nile.fcast <- meanf(Nile, h = 10)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.