| forecast.theta_model | R Documentation |
Returns forecasts and prediction intervals for a theta method forecast.
thetaf() is a convenience function that combines theta_model() and
forecast.theta_model().
The theta method of Assimakopoulos and Nikolopoulos (2000) is equivalent to
simple exponential smoothing with drift (Hyndman and Billah, 2003).
The series is tested for seasonality using the test outlined in A&N. If
deemed seasonal, the series is seasonally adjusted using a classical
multiplicative decomposition before applying the theta method. The resulting
forecasts are then reseasonalized.
Prediction intervals are computed using the underlying state space model.
## S3 method for class 'theta_model'
forecast(
object,
h = if (frequency(object$y) > 1) 2 * frequency(object$y) else 10,
level = c(80, 95),
fan = FALSE,
lambda = object$lambda,
biasadj = FALSE,
...
)
thetaf(
y,
h = if (frequency(y) > 1) 2 * frequency(y) else 10,
level = c(80, 95),
fan = FALSE,
lambda = NULL,
biasadj = FALSE,
x = y,
...
)
object |
An object of class |
h |
Number of periods for forecasting. Default value is twice the largest seasonal period (for seasonal data) or ten (for non-seasonal data). |
level |
Confidence levels for prediction intervals. |
fan |
If |
lambda |
Box-Cox transformation parameter. If |
biasadj |
Use adjusted back-transformed mean for Box-Cox
transformations. If transformed data is used to produce forecasts and fitted
values, a regular back transformation will result in median forecasts. If
biasadj is |
... |
Other arguments passed to |
y |
a numeric vector or univariate time series of class |
x |
Deprecated. Included for backwards compatibility. |
More general theta methods are available in the forecTheta package.
An object of class forecast.
An object of class forecast is a list usually containing at least
the following elements:
A list containing information about the fitted model
The name of the forecasting method as a character string
Point forecasts as a time series
Lower limits for prediction intervals
Upper limits for prediction intervals
The confidence values associated with the prediction intervals
The original time series.
Residuals from the fitted model. For models with additive errors, the residuals will be x minus the fitted values.
Fitted values (one-step forecasts)
The function summary can be used to obtain and print a summary of the
results, while the functions plot and autoplot produce plots of the forecasts and
prediction intervals. The generic accessor functions fitted.values and residuals
extract various useful features from the underlying model.
Rob J Hyndman
Assimakopoulos, V. and Nikolopoulos, K. (2000). The theta model: a decomposition approach to forecasting. International Journal of Forecasting 16, 521-530.
Hyndman, R.J., and Billah, B. (2003) Unmasking the Theta method. International J. Forecasting, 19, 287-290.
stats::arima(), meanf(), rwf(), ses()
nile_fit <- theta_model(Nile)
forecast(nile_fit) |> autoplot()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.