| forecast.ts | R Documentation |
forecast is a generic function for forecasting from time series or
time series models. The function invokes particular methods which
depend on the class of the first argument.
## S3 method for class 'ts'
forecast(
object,
h = if (frequency(object) > 1) 2 * frequency(object) else 10,
level = c(80, 95),
fan = FALSE,
robust = FALSE,
lambda = NULL,
biasadj = FALSE,
find.frequency = FALSE,
allow.multiplicative.trend = FALSE,
model = NULL,
...
)
## Default S3 method:
forecast(object, ...)
## S3 method for class 'forecast'
print(x, ...)
object |
a time series or time series model for which forecasts are required. |
h |
Number of periods for forecasting. Default value is twice the largest seasonal period (for seasonal data) or ten (for non-seasonal data). |
level |
Confidence levels for prediction intervals. |
fan |
If |
robust |
If |
lambda |
Box-Cox transformation parameter. If |
biasadj |
Use adjusted back-transformed mean for Box-Cox
transformations. If transformed data is used to produce forecasts and fitted
values, a regular back transformation will result in median forecasts. If
biasadj is |
find.frequency |
If |
allow.multiplicative.trend |
If |
model |
An object describing a time series model; e.g., one of class
|
... |
Additional arguments affecting the forecasts produced. If
|
x |
a numeric vector or time series of class |
For example, the function forecast.Arima() makes forecasts based
on the results produced by stats::arima().
If model = NULL, the function forecast.ts() makes forecasts
using ets() models (if the data are non-seasonal or the seasonal
period is 12 or less) or stlf() (if the seasonal period is 13 or
more).
If model is not NULL, forecast.ts will apply the
model to the object time series, and then generate forecasts
accordingly.
An object of class forecast.
An object of class forecast is a list usually containing at least
the following elements:
A list containing information about the fitted model
The name of the forecasting method as a character string
Point forecasts as a time series
Lower limits for prediction intervals
Upper limits for prediction intervals
The confidence values associated with the prediction intervals
The original time series.
Residuals from the fitted model. For models with additive errors, the residuals will be x minus the fitted values.
Fitted values (one-step forecasts)
The function summary can be used to obtain and print a summary of the
results, while the functions plot and autoplot produce plots of the forecasts and
prediction intervals. The generic accessor functions fitted.values and residuals
extract various useful features from the underlying model.
Rob J Hyndman
Other functions which return objects of class forecast are
forecast.ets(), forecast.Arima(), forecast.HoltWinters(),
forecast.StructTS(), meanf(), rwf(), splinef(), thetaf(),
croston(), ses(), holt(), hw().
WWWusage |> forecast() |> plot()
fit <- ets(window(WWWusage, end = 60))
fc <- forecast(WWWusage, model = fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.