| arimaorder | R Documentation |
Returns the order of a univariate ARIMA or ARFIMA model.
arimaorder(object)
object |
An object of class |
A numerical vector giving the values p, d and q of
the ARIMA or ARFIMA model. For a seasonal ARIMA model, the returned vector
contains the values p, d, q, P, D, Q and
m, where m is the period of seasonality.
Rob J Hyndman
stats::ar(), auto.arima, Arima(), stats::arima(), arfima().
WWWusage |> auto.arima() |> arimaorder()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.