## S3 method for class 'Arima':
forecast(object, h=ifelse(object$arma[5]>1,2*object$arma[5],10),
level=c(80,95), fan=FALSE, xreg=NULL,...)
## S3 method for class 'ar':
forecast(object, h=10, level=c(80,95), fan=FALSE, ...)xreg is used, h is ignored and the number of forecast periods is set to the number of rows of xreg.Arima objects only).forecast".
The function summary is used to obtain and print a summary of the
results, while the function plot produces a plot of the forecasts and prediction intervals.
The generic accessor functions fitted.values and residuals extract useful features of
the value returned by forecast.Arima.
An object of class "forecast" is a list containing at least the following elements:object itself or the time series used to create the model stored as object).predict.arima or predict.ar and constructs an object of class "forecast" from the results.predict.arima, ar, arima, rwf.fit <- Arima(WWWusage,c(3,1,0))
plot(forecast(fit))Run the code above in your browser using DataLab