| forecast.mts | R Documentation |
mforecast is a class of objects for forecasting from multivariate
time series or multivariate time series models. The function invokes
particular methods which depend on the class of the first argument.
## S3 method for class 'mts'
forecast(
object,
h = if (frequency(object) > 1) 2 * frequency(object) else 10,
level = c(80, 95),
fan = FALSE,
robust = FALSE,
lambda = NULL,
biasadj = FALSE,
find.frequency = FALSE,
allow.multiplicative.trend = FALSE,
...
)
object |
a multivariate time series or multivariate time series model for which forecasts are required |
h |
Number of periods for forecasting. Default value is twice the largest seasonal period (for seasonal data) or ten (for non-seasonal data). |
level |
Confidence levels for prediction intervals. |
fan |
If |
robust |
If |
lambda |
Box-Cox transformation parameter. If |
biasadj |
Use adjusted back-transformed mean for Box-Cox
transformations. If transformed data is used to produce forecasts and fitted
values, a regular back transformation will result in median forecasts. If
biasadj is |
find.frequency |
If |
allow.multiplicative.trend |
If |
... |
Additional arguments affecting the forecasts produced. |
For example, the function forecast.mlm() makes multivariate
forecasts based on the results produced by tslm().
An object of class mforecast.
The function summary is used to obtain and print a summary of the
results, while the function plot produces a plot of the multivariate
forecasts and prediction intervals.
The generic accessor functions fitted.values and residuals
extract various useful features of the value returned by forecast$model.
An object of class mforecast is a list usually containing at least
the following elements:
model |
A list containing information about the fitted model |
method |
The name of the forecasting method as a character string |
mean |
Point forecasts as a time series |
lower |
Lower limits for prediction intervals |
upper |
Upper limits for prediction intervals |
level |
The confidence values associated with the prediction intervals |
x |
The original time series (either |
residuals |
Residuals from the fitted model. For models with additive errors, the residuals will be x minus the fitted values. |
fitted |
Fitted values (one-step forecasts) |
Rob J Hyndman & Mitchell O'Hara-Wild
Other functions which return objects of class mforecast
are forecast.mlm(), forecast.varest().
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.