| forecast.nnetar | R Documentation |
Returns forecasts and other information for univariate neural network models.
## S3 method for class 'nnetar'
forecast(
object,
h = if (object$m > 1) 2 * object$m else 10,
PI = FALSE,
level = c(80, 95),
fan = FALSE,
xreg = NULL,
lambda = object$lambda,
bootstrap = FALSE,
npaths = 1000,
innov = NULL,
...
)
object |
An object of class |
h |
Number of periods for forecasting. If |
PI |
If |
level |
Confidence levels for prediction intervals. |
fan |
If |
xreg |
Future values of any regression variables. A numerical vector or matrix of external regressors; it should not be a data frame. |
lambda |
Box-Cox transformation parameter. If |
bootstrap |
If |
npaths |
Number of sample paths used in computing simulated prediction intervals. |
innov |
Values to use as innovations for prediction intervals. Must be
a matrix with |
... |
Additional arguments passed to |
Prediction intervals are calculated through simulations and can be slow. Note that if the network is too complex and overfits the data, the residuals can be arbitrarily small; if used for prediction interval calculations, they could lead to misleadingly small values. It is possible to use out-of-sample residuals to ameliorate this, see examples.
An object of class forecast.
An object of class forecast is a list usually containing at least
the following elements:
A list containing information about the fitted model
The name of the forecasting method as a character string
Point forecasts as a time series
Lower limits for prediction intervals
Upper limits for prediction intervals
The confidence values associated with the prediction intervals
The original time series.
Residuals from the fitted model. For models with additive errors, the residuals will be x minus the fitted values.
Fitted values (one-step forecasts)
The function summary can be used to obtain and print a summary of the
results, while the functions plot and autoplot produce plots of the forecasts and
prediction intervals. The generic accessor functions fitted.values and residuals
extract various useful features from the underlying model.
Rob J Hyndman and Gabriel Caceres
nnetar().
## Fit & forecast model
fit <- nnetar(USAccDeaths, size = 2)
fcast <- forecast(fit, h = 20)
plot(fcast)
## Not run:
## Include prediction intervals in forecast
fcast2 <- forecast(fit, h = 20, PI = TRUE, npaths = 100)
plot(fcast2)
## Set up out-of-sample innovations using cross-validation
fit_cv <- CVar(USAccDeaths, size = 2)
res_sd <- sd(fit_cv$residuals, na.rm = TRUE)
myinnovs <- rnorm(20 * 100, mean = 0, sd = res_sd)
## Forecast using new innovations
fcast3 <- forecast(fit, h = 20, PI = TRUE, npaths = 100, innov = myinnovs)
plot(fcast3)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.