| plot.ets | R Documentation |
Produces a plot of the level, slope and seasonal components from an ETS model.
## S3 method for class 'ets'
plot(x, ...)
## S3 method for class 'ets'
autoplot(object, range.bars = NULL, ...)
x |
Object of class “ets”. |
... |
Other plotting parameters to affect the plot. |
object |
Object of class “ets”. Used for ggplot graphics (S3 method consistency). |
range.bars |
Logical indicating if each plot should have a bar at its
right side representing relative size. If |
autoplot will produce an equivalent plot as a ggplot object.
None. Function produces a plot
Rob J Hyndman & Mitchell O'Hara-Wild
ets()
fit <- ets(USAccDeaths)
plot(fit)
plot(fit, plot.type = "single", ylab = "", col = 1:3)
library(ggplot2)
autoplot(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.