| theta_model | R Documentation |
The theta method of Assimakopoulos and Nikolopoulos (2000) is equivalent to simple exponential smoothing with drift (Hyndman and Billah, 2003). This function fits the theta model to a time series. The series is tested for seasonality using the test outlined in A&N. If deemed seasonal, the series is seasonally adjusted using a classical multiplicative decomposition before fitting the theta model.
theta_model(y, lambda = NULL, biasadj = FALSE)
y |
a numeric vector or univariate time series of class |
lambda |
Box-Cox transformation parameter. If |
biasadj |
Use adjusted back-transformed mean for Box-Cox
transformations. If transformed data is used to produce forecasts and fitted
values, a regular back transformation will result in median forecasts. If
biasadj is |
More general theta methods are available in the forecTheta package.
An object of class theta_model.
Rob J Hyndman
Assimakopoulos, V. and Nikolopoulos, K. (2000). The theta model: a decomposition approach to forecasting. International Journal of Forecasting 16, 521-530.
Hyndman, R.J., and Billah, B. (2003) Unmasking the Theta method. International J. Forecasting, 19, 287-290.
thetaf()
nile_fit <- theta_model(Nile)
forecast(nile_fit) |> autoplot()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.